#
# spec file for package python-ZEO
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python2
Name:           python-ZEO
Version:        5.4.0
Release:        1.3
Summary:        Client-Server storage implementation for ZODB
License:        ZPL-2.1
URL:            https://github.com/zopefoundation/ZEO
Source:         https://files.pythonhosted.org/packages/source/Z/ZEO/ZEO-%{version}.tar.gz
# https://github.com/zopefoundation/ZEO/issues/184
Patch0:         python-ZEO-no-mock.patch
# https://github.com/zopefoundation/ZEO/commit/d0f0709ac617a1e3d1251f396682a3bb79e22211
Patch1:         python-ZEO-no-six.patch
BuildRequires:  %{python_module ZConfig}
BuildRequires:  %{python_module ZODB >= 5.5.1}
BuildRequires:  %{python_module manuel}
BuildRequires:  %{python_module msgpack}
BuildRequires:  %{python_module random2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module transaction >= 2.0.3}
BuildRequires:  %{python_module zc.lockfile}
BuildRequires:  %{python_module zdaemon}
BuildRequires:  %{python_module zodbpickle >= 0.6.0}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ZConfig
Requires:       python-ZODB >= 5.5.1
Requires:       python-persistent >= 4.1.0
Requires:       python-transaction >= 2.0.3
Requires:       python-zc.lockfile
Requires:       python-zdaemon
Requires:       python-zope.interface
Requires(post): update-alternatives
Requires(preun):update-alternatives
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-futures
BuildRequires:  python-trollius
%endif
%ifpython2
Requires:       python-trollius
%endif
%python_subpackages

%description
ZEO provides a client-server storage implementation for ZODB.

%package     -n %{name}-doc
Summary:        Client-Server storage implementation for ZODB
Provides:       %{python_module ZEO-doc = %{version}}

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n ZEO-%{version}
%autopatch -p1

# delete backup files
find . -name "*~" -print -delete
# remove unwanted shebang
find src -name "*.py" | xargs sed -i '1 { /^#!/ d }'
rm -rf src/ZEO.egg-info
# do not hardcode version
sed -i -e 's:msgpack < 0.6:msgpack:g' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/runzeo
%python_clone -a %{buildroot}%{_bindir}/zeoctl
%python_clone -a %{buildroot}%{_bindir}/zeopack
%python_clone -a %{buildroot}%{_bindir}/zeo-nagios

%check
pushd src
export ZEO4_SERVER=1
%pyunittest -v ZEO/tests/test*.py

%post
%python_install_alternative runzeo zeoctl zeopack zeo-nagios

%postun
%python_uninstall_alternative runzeo

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst COPYRIGHT.txt README.rst
%python_alternative %{_bindir}/runzeo
%python_alternative %{_bindir}/zeoctl
%python_alternative %{_bindir}/zeopack
%python_alternative %{_bindir}/zeo-nagios
%{python_sitelib}/ZEO
%{python_sitelib}/ZEO-%{version}-py%{python_version}.egg-info

%changelog
* Mon Apr  3 2023 pgajdos@suse.com
- version update to 5.4.0
  * Reimplement and streamline the asyncio part of the ClientStorage implementation.
  * Remove support for interoperability with ZEO4 server.
  * If the zeopack script cannot connect to a server it sets exit status 1 See #214.
  * Remove asyncio/mtacceptor module.
  * Add support for Python 3.10, 3.11.
  * Add ConflictError to the list of unlogged server exceptions.
- do not require six
- modified patches
  %% python-ZEO-no-mock.patch (refreshed)
- added patches
  fix https://github.com/zopefoundation/ZEO/commit/d0f0709ac617a1e3d1251f396682a3bb79e22211
  + python-ZEO-no-six.patch
* Mon Aug 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 5.3.0
  * Remove tests for the asyncio/mtacceptor module, it appears unused and presents a maintenance
    burden. The module will be removed in ZEO version 6.
  * Remove GitHub Actions testing for Python 3.5, it has reached end of life.
  * Add support for Python 3.8 and Python 3.9.
  * Add more accurate error handling for asyncio.CancelledError. See issue 165.
  * Fix bug related to blobs stored by ZEO #150.
* Mon Feb 28 2022 Matej Cepl <mcepl@suse.com>
- Set ZEO4_SERVER env. variable to skip expected failing tests.
* Fri Sep 24 2021 pgajdos@suse.com
- added patches
  fix https://github.com/zopefoundation/ZEO/issues/184
  + python-ZEO-no-mock.patch
* Fri Sep 24 2021 pgajdos@suse.com
-
- added patches
  fix https://github.com/zopefoundation/ZEO/issues/184
  + python-ZEO-no-mock.patch
* Fri Sep 24 2021 pgajdos@suse.com
- version update to 5.2.3
  5.2.3 (2021-08-09)
  - -----------------
  - Ensure ``ZEO`` satisfies the ``ZODB >= 5.6`` requirement that
    ``lastTransaction()`` changes only after invalidation processing.
    Violating this requirement can lead to race conditions and
    associated data corruption
    `#166 <https://github.com/zopefoundation/ZEO/issues/166>`_.
  - Add automated tests against the ZODB ``master`` branch
    see `issue 177 <https://github.com/zopefoundation/ZEO/issues/177>`_.
  - Fix data corruption due to race between load and external invalidations.
    See `issue 155 <https://github.com/zopefoundation/ZEO/issues/155>`_.
  - Improve log message when client cache is out of sync with server.
    See `issue 142 <https://github.com/zopefoundation/ZEO/issues/142>`_.
  5.2.2 (2020-08-11)
  - -----------------
  - Remove support for Python 3.4
  - Provide proper CA test certificates to allow the SSL tests succeed for Py3
  - Replace deprecated occurrences of ``Thread.isAlive()`` by ``Thread.is_alive()``
    See `pull request 154 <https://github.com/zopefoundation/ZEO/pull/154>`_.
  - Include both modified and just created objects into invalidations.
    See `pull request 160 <https://github.com/zopefoundation/ZEO/pull/160>`_.
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Mar 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove msgpack restriction to < 0.6 release
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.2.1:
  * Add support for Python 3.7.
  * Switch from msgpack-python to msgpack. Currently a version < 0.6 is required.
  * Stop calling the deprecated checkSecure method when creating a ClientStorage. With ZODB 5.2.2 and above, this issued a warning. With older versions, this could issue a log message, but this was considered a misfeature. See issue 134.
* Tue Jul 31 2018 tchvatal@suse.com
- Add zdaemon as test dependency
* Wed May  2 2018 tchvatal@suse.com
- Change url to match up with upstream
- Update to release 5.2.0:
  * Fixed: The quickstart/ad-hoc/play ZEO server relied on test
    dependencies. See `issue 105
    <https://github.com/zopefoundation/ZEO/issues/105>`_.
  * Disallow passing strings as addresses to ClientStorage under Windows
    because string addresses are used for unix-domain sockets, which
    aren't supported on Windows. See `issue 107
    <https://github.com/zopefoundation/ZEO/issues/107>`_.
  * Renamed all ``async`` attributes to ``async_`` for compatibility
    with Python 3.7. See `issue 104
    <https://github.com/zopefoundation/ZEO/issues/104>`_.
  * Fixed to work with some changes made in ZODB 5.4.0.
    Client-side updates are incuded for ZODB 5.4.0 or databases that
    already had ``zodbpickle.binary`` OIDs. See `issue 113
    <https://github.com/zopefoundation/ZEO/issues/113>`_.
  * ZEO now uses pickle protocol 3 for both Python 2 and Python 3.
    (Previously protocol 1 was used for Python 2.) This matches the
    change in ZODB 5.4.0.
- Drop the docs as they are present on web and fail to build with
  current sphinx
* Fri Sep 15 2017 toddrme2178@gmail.com
- Fix python-trollius detection
* Fri Aug 25 2017 toddrme2178@gmail.com
- Fix doc package dependencies
* Mon Jul 17 2017 toddrme2178@gmail.com
- Use same package names from requires and buildrequires to avoid
  packaging issues.
* Sun Jul  9 2017 aloisio@gmx.com
- Update to version 5.1.0 (see CHANGES.rst)
- Converted to single-spec
- Added python-ZEO-rpmlintrc
- Enabled tests
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.0:
  * Add support for Python 3.4.
  * Added a new ruok client protocol for getting server status on
    the ZEO port without creating a full-blown client connection
    and without logging in the server log.
  * Log errors on server side even if using multi threaded delay.
- additional changes from version 4.0.0:
  * Avoid reading excess random bytes when setting up an
    auth_digest session.
  * Optimize socket address enumeration in ZEO client (avoid
    non-TCP types).
  * Improve Travis CI testing support.
  * Assign names to all threads for better runtime debugging.
  * Fix "assignment to keyword" error under Py3k in
    ‘ZEO.scripts.zeoqueue’.
- delete backup files found in the sources
- remove unwanted shebang of python files
- do not set the executable bit of python files
- fix update-alternatives: add %%{_sysconfdir}/alternatives/...
- add new binary zeo-nagios
- update documentation files: changed upstream
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Tue Sep 10 2013 hpj@urpla.net
- package supports update-alternatives now
* Tue Aug  6 2013 hpj@urpla.net
- version 4.0.0b1: initial build
